apply_score_threshold: Applies Score Threshold to Predictions and Calculates...

View source: R/apply_score_threshold.R

apply_score_thresholdR Documentation

Applies Score Threshold to Predictions and Calculates confidence that the image is empty

Description

This function removes detections that fall below the score_threshold. When an image has all detections removed it is assigned a value of 'empty'. The confidence in the prediction that the image is empty is calculated as 1 - max(x) where x is a vector of confidence values for the detections that fall below score threshold. So the confidence that the image is empty is assumed to be directly related to the largest confidence in the detections that will be removed.

Usage

apply_score_threshold(df, file_list, score_threshold)

Arguments

df

Dataframe of predictions from model

file_list

Vector of file names processed by model

score_threshold

Threshold score for keeping bounding boxes


TabakM/CameraTrapDetectoR documentation built on June 11, 2022, 9:37 p.m.