reduce_overlapping_bboxes: Find overlapping bounding boxes and return classification...

View source: R/reduce_overlapping_bboxes.R

reduce_overlapping_bboxesR Documentation

Find overlapping bounding boxes and return classification with maximum confidence

Description

Evaluates overlapping bounding boxes using user specified threshold that determines overlap and returns bounding boxes and classification with maximum confidence

Usage

reduce_overlapping_bboxes(df, overlap_threshold = 0.8)

Arguments

df

The data frame containing bounding box values and predictions

overlap_threshold

The threshold (proportion) used in determining which bounding boxes are considered unique detections


TabakM/CameraTrapDetectoR documentation built on June 11, 2022, 9:37 p.m.