View source: R/apply_score_threshold.R
| apply_score_threshold | R Documentation |
This function removes detections that fall below the score_threshold. When an image has all detections removed it is assigned a value of 'empty'. The confidence in the prediction that the image is empty is calculated as 1 - max(x) where x is a vector of confidence values for the detections that fall below score threshold. So the confidence that the image is empty is assumed to be directly related to the largest confidence in the detections that will be removed.
apply_score_threshold(df, file_list, score_threshold)
df |
Dataframe of predictions from model |
file_list |
Vector of file names processed by model |
score_threshold |
Threshold score for keeping bounding boxes |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.