View source: R/reduce_overlapping_bboxes.R
| reduce_overlapping_bboxes | R Documentation |
Evaluates overlapping bounding boxes using user specified threshold that determines overlap and returns bounding boxes and classification with maximum confidence
reduce_overlapping_bboxes(df, overlap_threshold = 0.8)
df |
The data frame containing bounding box values and predictions |
overlap_threshold |
The threshold (proportion) used in determining which bounding boxes are considered unique detections |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.